library ieee;
use ieee.std_logic_1164.all;
use ieee.std_logic_arith.all;
use ieee.std_logic_unsigned.all;

entity project_top_level is
        port
        (
					-- 7 segment displays
					HEX0 : out std_logic_vector (6 downto 0);
					HEX1 : out std_logic_vector (6 downto 0);
					HEX2 : out std_logic_vector (6 downto 0);
					HEX3 : out std_logic_vector (6 downto 0);
					HEX4 : out std_logic_vector (6 downto 0);
					HEX5 : out std_logic_vector (6 downto 0);
					HEX6 : out std_logic_vector (6 downto 0);
					HEX7 : out std_logic_vector (6 downto 0);
					 
                			-- I2C TV Chip Connections
					I2C_SCLK : out std_logic;
					I2C_SDAT : inout std_logic;

					-- TV ports
					TD_DATA  : in std_logic_vector (7 downto 0);
					TD_HS    : in std_logic;
					TD_VS    : in std_logic;
					TD_RESET : out std_logic;

					-- CLOCK port
					CLOCK_50        :       in  std_logic;
					CLOCK_27        :       in  std_logic;
					TD_CLK		:	in  std_logic;					 
					
					 -- switch
					SW		:	in  STD_LOGIC_VECTOR(17 downto 0);

					-- RESET key
                			KEY : in  std_logic_vector(3 downto 0)
				);	
end project_top_level;


-- Library Clause(s) (optional)
-- Use Clause(s) (optional)

architecture structure of project_top_level is


component i2c_av_config

    port(
	    -- Host Side
	    iCLK   : in std_logic;
	    iRST_N : in std_logic;

	    -- I2C Side
	    I2C_SCLK : out std_logic;
	    I2C_SDAT : inout std_logic
    );

end component i2c_av_config;


component BALL_TRAJECTORY

    port(
	    -- Clock
	    signal CLK_50 : IN STD_LOGIC;
	    -- Reset
	    signal RESET : IN STD_LOGIC;
	    -- Control Inputs
	    signal switch : IN STD_LOGIC_VECTOR (17 downto 0);
	    -- 7-SEG Display
	    signal HEX0 : OUT STD_LOGIC_VECTOR (6 downto 0);						
	    signal HEX1 : OUT STD_LOGIC_VECTOR (6 downto 0);							
	    signal HEX2 : OUT STD_LOGIC_VECTOR (6 downto 0);								
	    signal HEX3 : OUT STD_LOGIC_VECTOR (6 downto 0);								
	    signal HEX4 : OUT STD_LOGIC_VECTOR (6 downto 0);								
	    signal HEX5 : OUT STD_LOGIC_VECTOR (6 downto 0);								
	    signal HEX6 : OUT STD_LOGIC_VECTOR (6 downto 0);								
	    signal HEX7 : OUT STD_LOGIC_VECTOR (6 downto 0);								
	    -- TV Decoder
	    signal TD_DATA  : IN STD_LOGIC_VECTOR (7 downto 0);   						
	    signal TD_HS    : IN STD_LOGIC;					
	    signal TD_VS    : IN STD_LOGIC;
	    signal TD_RESET : OUT STD_LOGIC;						
	    signal TD_CLK   : IN STD_LOGIC;
	    -- Tracker outputs
	    signal TRACKED_x : out STD_LOGIC_VECTOR (9 downto 0);
	    signal TRACKED_y : out STD_LOGIC_VECTOR (9 downto 0)							
    );

end component BALL_TRAJECTORY;



	signal tracked_x : std_logic_vector (9 downto 0);
	signal tracked_y : std_logic_vector (9 downto 0);

begin


	f0: i2c_av_config port map ( CLOCK_50, KEY(0), I2C_SCLK, I2C_SDAT );


	f1: BALL_TRAJECTORY port map (CLK_50 	   => CLOCK_50,
				      RESET	   => KEY(0),
				      switch       => SW,
				      HEX0	   => HEX0,						
			 	      HEX1	   => HEX1,						
				      HEX2	   => HEX2,						
	 			      HEX3	   => HEX3,						
	 			      HEX4	   => HEX4,						
				      HEX5	   => HEX5,
				      HEX6	   => HEX6,
				      HEX7	   => HEX7,					
				      TD_DATA      => TD_DATA,    			
				      TD_HS	   => TD_HS,						
				      TD_VS	   => TD_VS,					
				      TD_RESET     => TD_RESET,						
				      TD_CLK       => TD_CLK,
				      TRACKED_x	   => tracked_x,
				      TRACKED_y    => tracked_y		);
	
	
		  
end structure;
		  
